@@ -3,7 +3,7 @@
 import logging
 from typing import Any
 from collections import abc
-from pydantic.json import pydantic_encoder
+import pydantic
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -25,10 +25,11 @@ def _loop_over_dict(obj) -> dict:
 def encode_pydantic_obj(obj: Any) -> Any:
     """Take an object and encode it to basic python types iteratively.
 
-    The result should be ready to be encoded to TOML (Or another data type).
+    The result should be ready to be encoded to TOML (Or another data type) without
+    the need for a special encoder.
     """
     try:
-        result = pydantic_encoder(obj)
+        result = pydantic.json.pydantic_encoder(obj)
     except TypeError:
         result = obj
 
